<?php
declare(strict_types=1);

namespace FiloBlu\Core\Model;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Serialize\SerializerInterface;
use RuntimeException;

/**
 * Class Configuration
 * @package FiloBlu\Core\Helper
 */
class Configuration
{

    const XML_PATH_FILO_GENERAL_MAPPING = 'filoblu/general/mapping';

    const XML_PATH_FILO_GENERAL_MULTIDOMAIN = 'filoblu/general/multidomain';

    const XML_PATH_FILO_GENERAL_PROJECT_ID = 'filoblu/general/project_id';


    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var SerializerInterface
     */
    private $serializer;

    private $mapping;

    /**
     * Configuration constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param SerializerInterface $serializer
     */
    public function __construct(ScopeConfigInterface $scopeConfig, SerializerInterface $serializer)
    {
        $this->scopeConfig = $scopeConfig;
        $this->serializer = $serializer;
    }

    /**
     * @param null $scope
     * @return string
     */
    public function getProjectId($scope = null)
    {
        if (!$this->isMultiDomain()) {
            return $this->scopeConfig->getValue(self::XML_PATH_FILO_GENERAL_PROJECT_ID);
        }

        foreach ($this->getWebsiteMapping() as $map) {
            if (in_array($scope->getCode(), $map['websites'])) {
                return $map['project_id'];
            }
        }


       throw new RuntimeException('No project id available');
    }

    /**
     * @return bool
     */
    public function isMultiDomain() : bool
    {
        return $this->scopeConfig->isSetFlag(self::XML_PATH_FILO_GENERAL_MULTIDOMAIN);
    }

    /**
     * @return array
     */
    public function getWebsiteMapping()
    {
        if (!$this->mapping) {
            $this->mapping = $this->serializer->unserialize($this->scopeConfig->getValue(self::XML_PATH_FILO_GENERAL_MAPPING));
        }
        return $this->mapping;
    }

    /**
     * @return array
     */
    public function getProjectIds(): array
    {
        $ids = [];

        foreach ($this->getWebsiteMapping() as $map) {
            $ids[] = $map['project_id'];
        }

        return array_unique($ids);
    }
}
